@@ -2,9 +2,6 @@ import fire
 from cloudmask import __version__
 
 class CloudMaskCLI:
-    def __init__(self):
-        pass
-
     @staticmethod
     def version():
         return __version__
